@@ -208,6 +208,8 @@ rotate_mirror_translate (cairo_t * cr, double radius, double x, double y,
 }
 
 /* Nodoka gradient */
+/* Use this as close to drawing function as possible, on some systems these
+   settings get removed if cairo_clip(_preserve) () is called */
 static void
 nodoka_set_gradient (cairo_t * cr, const NodokaRGB * color, double top_hilight,
 					  double bottom_hilight, double gradient_center, int width,
@@ -217,7 +219,7 @@ nodoka_set_gradient (cairo_t * cr, const NodokaRGB * color, double top_hilight,
 	/* If we are not transparent, don't draw transparently */
 	if (!(transparent))
 		alpha = 1.0;
-
+		
 	if (gradients)
 	{
 		cairo_pattern_t *pattern;
@@ -281,10 +283,11 @@ nodoka_draw_button (cairo_t * cr,
 					int x, int y, int width, int height)
 {
 	double xoffset = 0, yoffset = 0;
-	NodokaRGB *fill = (NodokaRGB *) & colors->bg[widget->state_type];
+	NodokaRGB fill;
 	NodokaRGB border_disabled = colors->shade[4];
 	NodokaRGB border_normal;
 	nodoka_shade (&colors->shade[6], &border_normal, 0.95);
+        nodoka_shade (&colors->bg[widget->state_type], &fill, 1.0);
 	double alpha = 1;
 
 	cairo_translate (cr, x, y);
@@ -297,16 +300,26 @@ nodoka_draw_button (cairo_t * cr,
 
 	if (widget->disabled)
 	{
-		border_disabled.r = border_disabled.r * (0.6) + fill->r * 0.4;
-		border_disabled.g = border_disabled.g * (0.6) + fill->g * 0.4;
-		border_disabled.b = border_disabled.b * (0.6) + fill->b * 0.4;
+		border_disabled.r = border_disabled.r * (0.6) + fill.r * 0.4;
+		border_disabled.g = border_disabled.g * (0.6) + fill.g * 0.4;
+		border_disabled.b = border_disabled.b * (0.6) + fill.b * 0.4;
 		alpha = 0.35;
 	}
 	else
 	{
-		border_normal.r = border_normal.r * (0.6) + fill->r * 0.4;
-		border_normal.g = border_normal.g * (0.6) + fill->g * 0.4;
-		border_normal.b = border_normal.b * (0.6) + fill->b * 0.4;
+		border_normal.r = border_normal.r * (0.6) + fill.r * 0.4;
+		border_normal.g = border_normal.g * (0.6) + fill.g * 0.4;
+		border_normal.b = border_normal.b * (0.6) + fill.b * 0.4;
+		if (widget->is_default)
+                {
+			border_normal.r = border_normal.r * 0.3 + colors->spot[1].r * 0.7;
+			border_normal.g = border_normal.g * 0.3 + colors->spot[1].g * 0.7;
+			border_normal.b = border_normal.b * 0.3 + colors->spot[1].b * 0.7;
+                        fill.r = fill.r * 0.9 + colors->spot[0].r * 0.1;
+                        fill.g = fill.g * 0.9 + colors->spot[0].g * 0.1;
+                        fill.b = fill.b * 0.9 + colors->spot[0].b * 0.1;
+
+                }
 	}
 
 	/* Draw background */
@@ -315,7 +328,7 @@ nodoka_draw_button (cairo_t * cr,
 								  height - (yoffset * 2) - 1,
 								  widget->roundness, widget->corners);
 
-	nodoka_set_gradient (cr, fill, (widget->active ? HOLLOW_TOP_HILIGHT
+	nodoka_set_gradient (cr, &fill, (widget->active ? HOLLOW_TOP_HILIGHT
 									 : BULGING_TOP_HILIGHT),
 						  (widget->active ? HOLLOW_BOTTOM_HILIGHT
 						   : BULGING_BOTTOM_HILIGHT),
@@ -352,13 +365,6 @@ nodoka_draw_button (cairo_t * cr,
 	}
 
 	/* Draw border */
-	if (widget->is_default)
-	{
-		border_normal.r = colors->spot[1].r * 0.3 + colors->spot[2].r * 0.7;
-		border_normal.g = colors->spot[1].g * 0.3 + colors->spot[2].g * 0.7;
-		border_normal.b = colors->spot[1].b * 0.3 + colors->spot[2].b * 0.7;
-	}
-
 	if (widget->disabled)
 		cairo_set_source_rgb (cr, border_disabled.r, border_disabled.g,
 							  border_disabled.b);
@@ -1382,19 +1388,15 @@ nodoka_draw_menuitem (cairo_t * cr,
 
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
-	nodoka_rounded_rectangle (cr, 0, 0, width, height,
+	nodoka_rounded_rectangle (cr, 0.5, 0.5, width - 1, height - 1,
 								  widget->roundness, widget->corners);
-
+		
 	nodoka_set_gradient (cr, fill, DARK_TOP_HILIGHT, DARK_BOTTOM_HILIGHT,
 						  GRADIENT_CENTER, 0, height, widget->gradients,
 						  FALSE, 1.0);
 
-	if (widget->roundness > 1)
-		cairo_clip_preserve (cr);
-	cairo_fill (cr);
+	cairo_fill_preserve (cr);
 
-	nodoka_rounded_rectangle (cr, 0.5, 0.5, width - 1, height - 1,
-							  widget->roundness, widget->corners);
 	cairo_set_source_rgba (cr, border->r, border->g, border->b, 0.8);
 	cairo_stroke (cr);
 }
