@@ -144,6 +144,8 @@ nodoka_style_draw_flat_box (DRAW_ARGS)
 		nodoka_sanitize_size (window, &width, &height);
 
 		nodoka_draw_tooltip (cr, colors, &params, x, y, width, height);
+
+		cairo_destroy (cr);
 	}
 	else if (DETAIL ("entry_bg") && !(widget && widget->parent && GTK_IS_TREE_VIEW (widget->parent)))
 	{
@@ -614,7 +616,10 @@ nodoka_style_draw_box (DRAW_ARGS)
 		nodoka_draw_list_view_header (cr, colors, &params, &header, x, y, width,
 									  height);
 	}
-	else if (DETAIL ("button") || DETAIL ("buttondefault"))
+        else if (DETAIL ("buttondefault"))
+        {
+	}
+	else if (DETAIL ("button"))
 	{
 		WidgetParameters params;
 		nodoka_set_widget_parameters (widget, style, state_type, &params);
